@@ -1,4 +1,5 @@
 import builtins
+import os
 import sys
 from array import array
 from collections import Counter, defaultdict, deque
@@ -43,7 +44,7 @@ def install(
     """Install automatic pretty printing in the Python REPL.
 
     Args:
-        console (Console, optional): Console instance or ``None`` to use global console. Defaults to None.        
+        console (Console, optional): Console instance or ``None`` to use global console. Defaults to None.
         overflow (Optional[OverflowMethod], optional): Overflow method. Defaults to "ignore".
         crop (Optional[bool], optional): Enable cropping of long lines. Defaults to False.
     """
@@ -70,14 +71,14 @@ def install(
 class Pretty:
     """A rich renderable that pretty prints an object.
 
-        Args:
-            _object (Any): An object to pretty print.
-            highlighter (HighlighterType, optional): Highlighter object to apply to result, or None for ReprHighlighter. Defaults to None.
-            indent_size (int, optional): Number of spaces in indent. Defaults to 4.
-            justify (JustifyMethod, optional): Justify method, or None for default. Defaults to None.
-            overflow (OverflowMethod, optional): Overflow method, or None for default. Defaults to None.
-            no_wrap (Optional[bool], optional): Disable word wrapping. Defaults to False.
-        """
+    Args:
+        _object (Any): An object to pretty print.
+        highlighter (HighlighterType, optional): Highlighter object to apply to result, or None for ReprHighlighter. Defaults to None.
+        indent_size (int, optional): Number of spaces in indent. Defaults to 4.
+        justify (JustifyMethod, optional): Justify method, or None for default. Defaults to None.
+        overflow (OverflowMethod, optional): Overflow method, or None for default. Defaults to None.
+        no_wrap (Optional[bool], optional): Disable word wrapping. Defaults to False.
+    """
 
     def __init__(
         self,
@@ -132,6 +133,7 @@ def _get_braces_for_array(_object: array) -> Tuple[str, str, str]:
 
 
 _BRACES: Dict[type, Callable[[Any], Tuple[str, str, str]]] = {
+    os._Environ: lambda _object: ("environ({", "})", "environ({})"),
     array: _get_braces_for_array,
     defaultdict: _get_braces_for_defaultdict,
     Counter: lambda _object: ("Counter({", "})", "Counter()"),
@@ -143,6 +145,7 @@ _BRACES: Dict[type, Callable[[Any], Tuple[str, str, str]]] = {
     tuple: lambda _object: ("(", ")", "tuple()"),
 }
 _CONTAINERS = tuple(_BRACES.keys())
+_MAPPING_CONTAINERS = (dict, os._Environ)
 
 
 @dataclass
@@ -285,15 +288,16 @@ def pretty_repr(
 
     def traverse(obj: Any, root: bool = False) -> _Node:
         """Walk the object depth first."""
-        if isinstance(obj, _CONTAINERS):
-
+        obj_type = type(obj)
+        if obj_type in _CONTAINERS:
             obj_id = id(obj)
+
             if obj_id in visited_ids:
                 # Recursion detected
                 return _Node(value_repr="...")
             push_visited(obj_id)
+            open_brace, close_brace, empty = _BRACES[obj_type](obj)
 
-            open_brace, close_brace, empty = _BRACES[type(obj)](obj)
             if obj:
                 children: List[_Node] = []
                 node = _Node(
@@ -303,7 +307,7 @@ def pretty_repr(
                     last=root,
                 )
                 append = children.append
-                if isinstance(obj, dict):
+                if isinstance(obj, _MAPPING_CONTAINERS):
                     for last, (key, child) in loop_last(obj.items()):
                         child_node = traverse(child)
                         child_node.key_repr = to_repr(key)
@@ -360,7 +364,14 @@ if __name__ == "__main__":  # pragma: no cover
             list, {"crumble": ["apple", "rhubarb", "butter", "sugar", "flour"]}
         ),
         "counter": Counter(
-            ["apple", "orange", "pear", "kumquat", "kumquat", "durian",]
+            [
+                "apple",
+                "orange",
+                "pear",
+                "kumquat",
+                "kumquat",
+                "durian",
+            ]
         ),
         "atomic": (False, True, None),
         "Broken": BrokenRepr(),
