@@ -136,7 +136,7 @@ class PygmentsSyntaxTheme(SyntaxTheme):
             try:
                 pygments_style = self._pygments_style_class.style_for_token(token_type)
             except KeyError:
-                style = Style()
+                style = Style.empty()
             else:
                 color = pygments_style["color"]
                 bgcolor = pygments_style["bgcolor"]
@@ -159,8 +159,8 @@ class ANSISyntaxTheme(SyntaxTheme):
 
     def __init__(self, style_map: Dict[TokenType, Style]) -> None:
         self.style_map = style_map
-        self._missing_style = Style()
-        self._background_style = Style()
+        self._missing_style = Style.empty()
+        self._background_style = Style.empty()
         self._style_cache: Dict[TokenType, Style] = {}
 
     def get_style_for_token(self, token_type: TokenType) -> Style:
@@ -208,6 +208,18 @@ class Syntax(JupyterMixin):
     _pygments_style_class: Type[PygmentsStyle]
     _theme: SyntaxTheme
 
+    @classmethod
+    def get_theme(cls, name: Union[str, SyntaxTheme]) -> SyntaxTheme:
+        """Get a syntax theme instance."""
+        if isinstance(name, SyntaxTheme):
+            return name
+        theme: SyntaxTheme
+        if name in RICH_SYNTAX_THEMES:
+            theme = ANSISyntaxTheme(RICH_SYNTAX_THEMES[name])
+        else:
+            theme = PygmentsSyntaxTheme(name)
+        return theme
+
     def __init__(
         self,
         code: str,
@@ -236,12 +248,7 @@ class Syntax(JupyterMixin):
         self.word_wrap = word_wrap
         self.background_color = background_color
 
-        if isinstance(theme, SyntaxTheme):
-            self._theme = theme
-        elif theme in RICH_SYNTAX_THEMES:
-            self._theme = ANSISyntaxTheme(RICH_SYNTAX_THEMES[theme])
-        else:
-            self._theme = PygmentsSyntaxTheme(theme)
+        self._theme = self.get_theme(theme)
 
     @classmethod
     def from_path(
@@ -397,7 +404,7 @@ class Syntax(JupyterMixin):
         """Get background, number, and highlight styles for line numbers."""
         background_style = self._get_base_style()
         if background_style.transaprent_background:
-            return Style(), Style(dim=True), Style()
+            return Style.empty(), Style(dim=True), Style.empty()
         if console.color_system in ("256", "truecolor"):
             number_style = Style.chain(
                 background_style,
